@@ -9,6 +9,7 @@ EQUIPMENT_TYPES = {
   "POWER_ONLY": "e9ced401-93d9-4bc9-9342-d020481133dc",
   "STEP_DECK": "09090c04-c19d-4ef2-8cae-605d69105494",
   "TANKER": "689e53ba-f44f-4702-8db4-9f706018fc56",
-  "RGN": "86bdf40d-539f-4e70-90a2-c5471f2604c3"
+  "RGN": "86bdf40d-539f-4e70-90a2-c5471f2604c3",
+  "CONTAINER": "42a8e1cf-c85b-4357-b229-a09c163b72f7"
 }
   
\ No newline at end of file
